"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class ApiKeySearch extends common_1.Kommand {
    async runSafe() {
        let query = {};
        if (this.flags.filter) {
            query = {
                match: {
                    description: this.flags.filter,
                },
            };
        }
        const result = await this.sdk.security.searchApiKeys(this.args.user, query, {
            from: 0,
            size: 100,
        });
        this.logOk(`${result.total} API Keys found for user ${this.args.user}`);
        if (result.total !== 0) {
            this.log("");
            for (const { _id, _source } of result.hits) {
                this.log(` - Key "${_id}"`);
                this.log(`    Description: ${_source.description}`);
                this.log(`    Fingerprint: ${_source.fingerprint}`);
                this.log(`    Expires at: ${_source.expiresAt}`);
            }
        }
    }
}
ApiKeySearch.description = "Lists a user's API Keys.";
ApiKeySearch.flags = Object.assign({ help: command_1.flags.help(), filter: command_1.flags.string({
        description: "Filter to match the API Key descriptions",
    }) }, kuzzle_1.kuzzleFlags);
ApiKeySearch.args = [{ name: "user", description: "User kuid", required: true }];
exports.default = ApiKeySearch;
