"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const listr_1 = (0, tslib_1.__importDefault)(require("listr"));
const common_1 = require("../../common");
const execute_1 = require("../../support/execute");
class AppScaffold extends common_1.Kommand {
    constructor() {
        super(...arguments);
        this.templatesDir = "/tmp/kuzzle-templates";
    }
    async runSafe() {
        const destination = this.args.destination;
        const flavor = this.flags.flavor;
        const tasks = new listr_1.default([
            {
                title: "Checking destination",
                task: async () => this.checkDestination(destination),
            },
            {
                title: "Prepare temporary folder",
                task: async () => this.prepareTemplate(),
            },
            {
                title: "Cloning template repository",
                task: async () => this.cloneTemplate(flavor)
            }, {
                title: "Copying template files",
                task: async () => this.copyTemplate(destination)
            },
            {
                title: "Cleaning up",
                task: async () => this.cleanup()
            }
        ]);
        await tasks.run();
        this.log("");
        this.logOk(`Scaffolding complete!`);
        this.logOk(`Use ${chalk_1.default.blue.bold(`cd ${destination} && docker compose up -d`)} to start your Kuzzle stack.`);
    }
    getRepo(flavor) {
        console.log(flavor);
        switch (flavor) {
            case "generic":
                return "template-kuzzle-project";
            case "iot":
                return "template-kiotp-project";
            default:
                return "template-kuzzle-project";
        }
    }
    async checkDestination(destination) {
        let process;
        try {
            process = await (0, execute_1.execute)("test", "-d", destination);
        }
        catch (error) {
            if (error.result.exitCode === 1) {
                // Destination directory does not exist
                return;
            }
        }
        if (process.exitCode === 0) {
            throw new Error(`Destination directory ${destination} already exists.`);
        }
    }
    async prepareTemplate() {
        await (0, execute_1.execute)("rm", "-rf", this.templatesDir);
    }
    async cloneTemplate(flavor) {
        const repo = this.getRepo(flavor);
        await (0, execute_1.execute)("git", "clone", "--depth=1", `https://github.com/kuzzleio/${repo}`, "--branch", "master", "--single-branch", this.templatesDir);
    }
    async copyTemplate(destination) {
        await (0, execute_1.execute)("cp", "-r", `${this.templatesDir}/`, `${destination}/`);
    }
    async cleanup() {
        await (0, execute_1.execute)("rm", "-rf", this.templatesDir);
    }
}
exports.default = AppScaffold;
AppScaffold.initSdk = false;
AppScaffold.description = "Scaffolds a new Kuzzle application";
AppScaffold.flags = {
    help: command_1.flags.help(),
    flavor: command_1.flags.string({
        default: "generic",
        description: `Template flavor ("generic", "iot").`,
    }),
};
AppScaffold.args = [
    {
        name: "destination",
        description: "Directory to scaffold the app",
        required: true,
    },
];
