"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const command_1 = require("@oclif/command");
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const node_emoji_1 = (0, tslib_1.__importDefault)(require("node-emoji"));
const common_1 = require("../../common");
const execute_1 = require("../../support/execute");
const checkPrerequisites_1 = require("../../support/docker/checkPrerequisites");
const kuzzleServicesFile = `
version: '3'

services:
  redis:
    image: redis:5
    ports:
      - "6379:6379"

  elasticsearch:
    image: kuzzleio/elasticsearch:7
    ports:
      - "9200:9200"
    ulimits:
      nofile: 65536
`;
class AppStartServices extends common_1.Kommand {
    async runSafe() {
        this.createKourouDir();
        const docoFilename = path_1.default.join(this.kourouDir, "kuzzle-services.yml");
        const successfullCheck = this.flags.check
            ? await (0, checkPrerequisites_1.checkPrerequisites)(this)
            : true;
        if (this.flags.check && successfullCheck) {
            this.log(`\n${node_emoji_1.default.get("ok_hand")} Prerequisites are ${chalk_1.default.green.bold("OK")}!`);
        }
        else if (this.flags.check && !successfullCheck) {
            throw new Error(`${node_emoji_1.default.get("shrug")} Your system doesn't satisfy all the prerequisites. Cannot run Kuzzle services.`);
        }
        this.log(chalk_1.default.grey(`\nWriting the Docker Compose file to ${docoFilename}...\n`));
        (0, fs_1.writeFileSync)(docoFilename, kuzzleServicesFile);
        // clean up
        await (0, execute_1.execute)("docker", "compose", "-f", docoFilename, "down");
        try {
            await (0, execute_1.execute)("docker", "compose", "-f", docoFilename, "up", "-d");
            this.logOk("Elasticsearch and Redis are booting in the background right now.");
            this.log(chalk_1.default.grey("\nTo watch the logs, run"));
            this.log(chalk_1.default.blue.bold(`  docker compose -f ${docoFilename} logs -f\n`));
            this.log(`  Elasticsearch port: ${chalk_1.default.bold("9200")}`);
            this.log(`          Redis port: ${chalk_1.default.bold("6379")}`);
        }
        catch (error) {
            this.logKo(` Something went wrong: ${error.message}`);
            this.log(chalk_1.default.grey("If you want to investigate the problem, try running"));
            this.log(chalk_1.default.grey(`  docker compose -f ${docoFilename} up\n`));
        }
    }
}
exports.default = AppStartServices;
AppStartServices.initSdk = false;
AppStartServices.description = "Starts Kuzzle services (Elasticsearch and Redis)";
AppStartServices.flags = {
    help: command_1.flags.help(),
    check: command_1.flags.boolean({
        description: "Check prerequisite before running services",
        default: false,
    }),
};
