"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class CollectionCreate extends common_1.Kommand {
    async runSafe() {
        const body = this.stdin ? this.stdin : this.args.body || "{}";
        if (!(await this.sdk.index.exists(this.args.index))) {
            await this.sdk.index.create(this.args.index);
            this.logInfo(`Index "${this.args.index}" created`);
        }
        await this.sdk.collection.create(this.args.index, this.args.collection, this.parseJs(body));
        this.logOk(`Collection "${this.args.index}":"${this.args.collection}" created`);
    }
}
exports.default = CollectionCreate;
CollectionCreate.description = "Creates a collection";
CollectionCreate.flags = Object.assign({ help: command_1.flags.help() }, kuzzle_1.kuzzleFlags);
CollectionCreate.args = [
    { name: "index", description: "Index name", required: true },
    { name: "collection", description: "Collection name", required: true },
    {
        name: "body",
        description: "Collection mappings and settings in JS or JSON format. Will be read from STDIN if available",
    },
];
CollectionCreate.readStdin = true;
