"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
const restore_collection_1 = require("../../support/restore-collection");
class CollectionImport extends common_1.Kommand {
    async runSafe() {
        this.logInfo(`Start importing dump from ${this.args.path}`);
        if (!this.flags["no-mappings"]) {
            const mappingsPath = path_1.default.join(this.args.path, "mappings.json");
            const dump = JSON.parse(fs_1.default.readFileSync(mappingsPath, "utf8"));
            await (0, restore_collection_1.restoreCollectionMappings)(this.sdk, dump, this.flags.index, this.flags.collection);
        }
        const { index, collection, total } = await (0, restore_collection_1.restoreCollectionData)(this.sdk, this.log.bind(this), Number(this.flags["batch-size"]), path_1.default.join(this.args.path, "documents.jsonl"), this.flags.index, this.flags.collection);
        this.logOk(`Successfully imported ${total} documents from "${this.args.path}" in "${index}:${collection}"`);
    }
}
exports.default = CollectionImport;
CollectionImport.keepAuth = true;
CollectionImport.description = "Imports a collection";
CollectionImport.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), "batch-size": command_1.flags.string({
        description: "Maximum batch size (see limits.documentsWriteCount config)",
        default: "200",
    }), index: command_1.flags.string({
        description: "If set, override the index destination name",
    }), collection: command_1.flags.string({
        description: "If set, override the collection destination name",
    }), "no-mappings": command_1.flags.boolean({
        description: "Skip collection mappings",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }) });
CollectionImport.args = [
    { name: "path", description: "Dump directory path", required: true },
];
