"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
const restore_collection_1 = require("../../support/restore-collection");
class CollectionMigrate extends common_1.Kommand {
    async runSafe() {
        this.logInfo(`Start migration documents with ${this.args.script} from ${this.args.path}`);
        const migrateDocument = this.getMigrationFunction();
        const { index, collection, total } = await (0, restore_collection_1.restoreCollectionData)(this.sdk, this.log.bind(this), Number(this.flags["batch-size"]), path_1.default.join(this.args.path, "documents.jsonl"), this.flags.index, this.flags.collection, migrateDocument);
        this.logOk(`Successfully migrated ${total} documents from "${this.args.path}" in "${index}:${collection}"`);
    }
    getMigrationFunction() {
        const migrationScript = fs_1.default.readFileSync(this.args.script, "utf8");
        let migrationFunction;
        {
            migrationFunction = eval(`var f = ${migrationScript}; f`);
        }
        return migrationFunction;
    }
}
exports.default = CollectionMigrate;
CollectionMigrate.keepAuth = true;
CollectionMigrate.description = "Migrate a collection by transforming documents from a dump file and importing them into Kuzzle";
CollectionMigrate.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), "batch-size": command_1.flags.string({
        description: "Maximum batch size (see limits.documentsWriteCount config)",
        default: "200",
    }), index: command_1.flags.string({
        description: "If set, override the index destination name",
    }), collection: command_1.flags.string({
        description: "If set, override the collection destination name",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }) });
CollectionMigrate.args = [
    { name: "script", description: "Migration script path", required: true },
    { name: "path", description: "Collection dump path", required: true },
];
