"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigKeyDiff = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const strip_json_comments_1 = (0, tslib_1.__importDefault)(require("strip-json-comments"));
const common_1 = require("../../common");
class ConfigKeyDiff extends common_1.Kommand {
    async runSafe() {
        if (!fs_1.default.existsSync(this.args.first)) {
            throw new Error(`File "${this.args.first}" does not exists`);
        }
        if (!fs_1.default.existsSync(this.args.second)) {
            throw new Error(`File "${this.args.second}" does not exists`);
        }
        const first = JSON.parse((0, strip_json_comments_1.default)(fs_1.default.readFileSync(this.args.first, "utf8")));
        const second = JSON.parse((0, strip_json_comments_1.default)(fs_1.default.readFileSync(this.args.second, "utf8")));
        const changes = this._keyChanges(first, second);
        if (lodash_1.default.isEmpty(changes)) {
            this.logOk("No differences between keys in the provided configurations");
            return;
        }
        this.logInfo("Found differences between keys in the provided configurations. In the second file:");
        for (const [path, change] of Object.entries(changes)) {
            this.log(` - key "${path}" ${change}`);
        }
        if (this.flags.strict) {
            throw new Error("Provided configuration contains different keys");
        }
    }
    // Returns path who had changed between two objects (inspired by https://gist.github.com/Yimiprod/7ee176597fef230d1451)
    _keyChanges(base, object) {
        const changes = {};
        const walkObject = (_base, _object, path = []) => {
            for (const key of Object.keys(_base)) {
                if (_object[key] === undefined) {
                    const ar = [];
                    const ar2 = [];
                    ar.concat(ar2);
                    changes[[...path, key].join(".")] = "was removed";
                }
            }
            for (const key of Object.keys(_object)) {
                if (_base[key] === undefined) {
                    changes[[...path, key].join(".")] = "was added";
                }
                else if (!lodash_1.default.isEqual(_object[key], _base[key]) &&
                    lodash_1.default.isObject(_object[key]) &&
                    lodash_1.default.isObject(_base[key])) {
                    walkObject(_base[key], _object[key], [...path, key]);
                }
                else if (this.flags.values && _base[key] !== _object[key]) {
                    changes[[...path, key].join(".")] = `value is "${_object[key]}" and was "${_base[key]}"`;
                }
            }
        };
        walkObject(base, object);
        return changes;
    }
}
exports.ConfigKeyDiff = ConfigKeyDiff;
ConfigKeyDiff.initSdk = false;
ConfigKeyDiff.description = "Returns differences between two Kuzzle configuration files (kuzzlerc)";
ConfigKeyDiff.examples = [
    "kourou config:diff config/local/kuzzlerc config/production/kuzzlerc",
];
ConfigKeyDiff.flags = {
    strict: command_1.flags.boolean({
        description: "Exit with an error if differences are found",
        default: false,
    }),
    values: command_1.flags.boolean({
        description: "Also displays value changes",
        default: false,
    }),
};
ConfigKeyDiff.args = [
    { name: "first", description: "First configuration file", required: true },
    {
        name: "second",
        description: "Second configuration file",
        required: true,
    },
];
