"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class DocumentSearch extends common_1.Kommand {
    async runSafe() {
        let request = {
            controller: "document",
            action: "search",
            index: this.args.index,
            collection: this.args.collection,
            from: this.flags.from,
            size: this.flags.size,
            scroll: this.flags.scroll,
            lang: this.flags.lang,
            body: {
                query: this.parseJs(this.args.query || "{}"),
                sort: this.parseJs(this.flags.sort),
            },
        };
        // allow to edit request before send
        if (this.flags.editor) {
            request = this.fromEditor(request, { json: true });
        }
        const { result } = await this.sdk.query(request);
        for (const document of (result === null || result === void 0 ? void 0 : result.hits) || []) {
            this.logInfo(`Document ID: ${document._id}`);
            this.log(`Content: ${JSON.stringify(document._source, null, 2)}`);
        }
        this.logOk(`${result === null || result === void 0 ? void 0 : result.hits.length} documents fetched on a total of ${result === null || result === void 0 ? void 0 : result.total}`);
    }
}
exports.default = DocumentSearch;
DocumentSearch.description = "Searches for documents";
DocumentSearch.examples = [
    "kourou document:search iot sensors '{ equals: { name: \"corona\" } }'",
    "kourou document:search iot sensors '{ match: { name: \"cOrOnna\" } }' -a lang=elasticsearch",
    "kourou document:search iot sensors --editor",
];
DocumentSearch.flags = Object.assign({ sort: command_1.flags.string({
        description: "Sort in JS or JSON format.",
        default: "{}",
    }), from: command_1.flags.string({
        description: "Optional offset",
    }), size: command_1.flags.string({
        description: "Optional page size",
    }), scroll: command_1.flags.string({
        description: "Optional scroll TTL",
    }), lang: command_1.flags.string({
        description: "Specify the query language to use",
        default: "koncorde",
    }), editor: command_1.flags.boolean({
        description: "Open an editor (EDITOR env variable) to edit the request before sending",
    }), help: command_1.flags.help() }, kuzzle_1.kuzzleFlags);
DocumentSearch.args = [
    { name: "index", description: "Index name", required: true },
    { name: "collection", description: "Collection name", required: true },
    { name: "query", description: "Search query in JS or JSON format." },
];
