"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsListAliases extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        try {
            const { body } = await esClient.cat.aliases({ format: 'json' });
            const elements = body
                .map((e) => ({ index: e.index, alias: e.alias }))
                .filter((e) => (this.flags.grep ? e.alias.match(new RegExp(this.flags.grep)) : true))
                .sort();
            this.log(JSON.stringify(elements, null, 2));
        }
        catch (error) {
            console.log(error);
        }
    }
}
exports.default = EsListAliases;
EsListAliases.initSdk = false;
EsListAliases.description = 'Lists available ES aliases';
EsListAliases.flags = {
    help: command_1.flags.help(),
    node: command_1.flags.string({
        char: 'n',
        description: 'Elasticsearch server URL',
        default: 'http://localhost:9200',
    }),
    grep: command_1.flags.string({
        char: 'g',
        description: 'Match output with pattern',
    }),
};
