"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsListIndex extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        try {
            const { body } = await esClient.cat.indices({ format: "json" });
            // nice typescript destructuring syntax (:
            const indexes = body
                .map(({ index }) => index)
                .filter((index) => this.flags.grep ? index.match(new RegExp(this.flags.grep)) : true)
                .sort();
            this.log(JSON.stringify(indexes, null, 2));
        }
        catch (error) {
            console.log(error);
        }
    }
}
exports.default = EsListIndex;
EsListIndex.initSdk = false;
EsListIndex.description = "Lists available ES indexes";
EsListIndex.flags = {
    help: command_1.flags.help(),
    node: command_1.flags.string({
        char: "n",
        description: "Elasticsearch server URL",
        default: "http://localhost:9200",
    }),
    grep: command_1.flags.string({
        char: "g",
        description: "Match output with pattern",
    }),
};
