"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsSnapshotsCreateRepository extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        const esRequest = {
            repository: this.args.repository,
            verify: true,
            body: {
                type: "fs",
                settings: {
                    location: this.args.location,
                    compress: this.flags.compress,
                },
            },
        };
        const response = await esClient.snapshot.createRepository(esRequest);
        this.logOk(`Success ${JSON.stringify(response.body)}`);
    }
}
exports.default = EsSnapshotsCreateRepository;
EsSnapshotsCreateRepository.initSdk = false;
EsSnapshotsCreateRepository.description = "Create a FS snapshot repository inside an ES instance";
EsSnapshotsCreateRepository.flags = {
    compress: command_1.flags.boolean({
        description: "Compress data when storing them",
        default: false,
    }),
    node: command_1.flags.string({
        char: "n",
        description: "Elasticsearch server URL",
        default: "http://localhost:9200",
    }),
    help: command_1.flags.help(),
};
EsSnapshotsCreateRepository.args = [
    { name: "repository", description: "ES repository name", required: true },
    {
        name: "location",
        description: "ES snapshot repository location",
        required: true,
    },
];
