"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsSnapshotsCreate extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        const esRequest = {
            repository: this.args.repository,
            snapshot: this.args.name,
            body: {
                indices: "*",
                include_global_state: false,
                partial: false,
            },
        };
        const response = await esClient.snapshot.create(esRequest);
        this.logOk(`Success ${JSON.stringify(response.body)}`);
    }
}
exports.default = EsSnapshotsCreate;
EsSnapshotsCreate.initSdk = false;
EsSnapshotsCreate.description = "Create a snapshot repository inside an ES instance";
EsSnapshotsCreate.flags = {
    node: command_1.flags.string({
        char: "n",
        description: "Elasticsearch server URL",
        default: "http://localhost:9200",
    }),
    help: command_1.flags.help(),
};
EsSnapshotsCreate.args = [
    { name: "repository", description: "ES repository name", required: true },
    { name: "name", description: "ES snapshot name", required: true },
];
