"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsSnapshotsList extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        const esRequest = {
            repository: this.args.repository,
            ignore_unavailable: true,
        };
        const response = await esClient.cat.snapshots(esRequest);
        const snapshots = response.body.split("\n").filter(Boolean);
        const result = [];
        for (const snapshot of snapshots) {
            const snap = snapshot.split(" ").filter(Boolean);
            result.push({
                name: snap[0],
                status: snap[1],
                timestampStart: snap[2],
                hourStart: snap[3],
                timeStampEnd: snap[4],
                hourEnd: snap[5],
                duration: snap[6],
            });
        }
        this.logOk(`Success: ${JSON.stringify(result, null, 2)}`);
    }
}
exports.default = EsSnapshotsList;
EsSnapshotsList.initSdk = false;
EsSnapshotsList.description = "List all snapshot from a repository acknowledge by an ES instance";
EsSnapshotsList.flags = {
    node: command_1.flags.string({
        char: "n",
        description: "Elasticsearch server URL",
        default: "http://localhost:9200",
    }),
    help: command_1.flags.help(),
};
EsSnapshotsList.args = [
    {
        name: "repository",
        description: "Name of repository from which to fetch the snapshot information",
        required: true,
    },
];
