"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("../../../common");
class EsSnapshotsRestore extends common_1.Kommand {
    async runSafe() {
        const esClient = new elasticsearch_1.Client({ node: this.flags.node });
        await esClient.indices.close({
            index: "*",
            expand_wildcards: "all",
        });
        const esRequest = {
            repository: this.args.repository,
            snapshot: this.args.name,
            body: {
                feature_states: ["none"],
                include_global_state: false,
                indices: "*",
            },
        };
        const response = await esClient.snapshot.restore(esRequest);
        this.logOk(`Success ${JSON.stringify(response.body)}`);
    }
}
exports.default = EsSnapshotsRestore;
EsSnapshotsRestore.initSdk = false;
EsSnapshotsRestore.description = "Restore a snapshot repository inside an ES instance";
EsSnapshotsRestore.flags = {
    node: command_1.flags.string({
        char: "n",
        description: "Elasticsearch server URL",
        default: "http://localhost:9200",
    }),
    help: command_1.flags.help(),
};
EsSnapshotsRestore.args = [
    { name: "repository", description: "ES repository name", required: true },
    { name: "name", description: "ES snapshot name", required: true },
];
