"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VaultEncrypt = void 0;
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const command_1 = require("@oclif/command");
const kuzzle_vault_1 = require("kuzzle-vault");
const common_1 = require("../../common");
class VaultEncrypt extends common_1.Kommand {
    async runSafe() {
        if (lodash_1.default.isEmpty(this.flags["vault-key"])) {
            throw new Error("A vault key must be provided");
        }
        if (lodash_1.default.isEmpty(this.args.file)) {
            throw new Error("A file must be provided");
        }
        let outputFile = `${this.args.file}.enc`;
        if (this.flags["output-file"]) {
            outputFile = this.flags["output-file"];
        }
        if (fs_1.default.existsSync(outputFile) && !this.flags.force) {
            throw new Error(`Output file "${outputFile}" already exists. Use -f flag to overwrite it.`);
        }
        const cryptonomicon = new kuzzle_vault_1.Cryptonomicon(this.flags["vault-key"]);
        if (!fs_1.default.existsSync(this.args.file)) {
            throw new Error(`File "${this.args.file}" does not exists`);
        }
        let content;
        try {
            content = fs_1.default.readFileSync(this.args.file, "utf8");
        }
        catch (error) {
            throw new Error(`Cannot read file "${this.args.file}": ${error.message}`);
        }
        const encryptedContent = cryptonomicon.encryptString(content);
        fs_1.default.writeFileSync(outputFile, encryptedContent);
        this.logOk(`File content successfully encrypted into ${outputFile}`);
    }
}
exports.VaultEncrypt = VaultEncrypt;
VaultEncrypt.initSdk = false;
VaultEncrypt.description = "Encrypts an entire file.";
VaultEncrypt.examples = [
    "kourou file:encrypt books/cryptonomicon.txt --vault-key <vault-key>",
    "kourou file:encrypt books/cryptonomicon.txt -o books/cryptonomicon.txt.enc --vault-key <vault-key>",
];
VaultEncrypt.flags = {
    force: command_1.flags.boolean({
        char: "f",
        description: "Overwrite the output file if it already exists",
    }),
    "output-file": command_1.flags.string({
        char: "o",
        description: "Output file (default: <filename>.enc)",
    }),
    "vault-key": command_1.flags.string({
        description: "Kuzzle Vault Key (or KUZZLE_VAULT_KEY)",
        default: process.env.KUZZLE_VAULT_KEY,
    }),
};
VaultEncrypt.args = [{ name: "file", description: "Filename", required: true }];
