"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileTest = void 0;
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const command_1 = require("@oclif/command");
const kuzzle_vault_1 = require("kuzzle-vault");
const common_1 = require("../../common");
class FileTest extends common_1.Kommand {
    async runSafe() {
        if (lodash_1.default.isEmpty(this.flags["vault-key"])) {
            throw new Error("A vault key must be provided");
        }
        if (lodash_1.default.isEmpty(this.args.file)) {
            throw new Error("An encrypted file must be provided");
        }
        if (!fs_1.default.existsSync(this.args.file)) {
            throw new Error(`Encrypted file "${this.args.file} does not exists`);
        }
        const cryptonomicon = new kuzzle_vault_1.Cryptonomicon(this.flags["vault-key"]);
        let encryptedContent;
        try {
            encryptedContent = fs_1.default.readFileSync(this.args.file, "utf8");
        }
        catch (error) {
            throw new Error(`Cannot read encrypted content from file "${this.args.file}": ${error.message}`);
        }
        try {
            cryptonomicon.decryptString(encryptedContent);
            this.logOk("Encrypted file can be decrypted");
        }
        catch (error) {
            this.logKo(`Encrypted file cannot be decrypted: ${error.message}`);
        }
    }
}
exports.FileTest = FileTest;
FileTest.initSdk = false;
FileTest.description = "Tests if an encrypted file can be decrypted.";
FileTest.examples = [
    "kourou file:test books/cryptonomicon.txt.enc --vault-key <vault-key>",
];
FileTest.flags = {
    "vault-key": command_1.flags.string({
        description: "Kuzzle Vault Key (or KUZZLE_VAULT_KEY)",
        default: process.env.KUZZLE_VAULT_KEY,
    }),
};
FileTest.args = [
    { name: "file", description: "Encrypted file", required: true },
];
