"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const cli_ux_1 = (0, tslib_1.__importDefault)(require("cli-ux"));
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
const dump_collection_1 = require("../../support/dump-collection");
class IndexExport extends common_1.Kommand {
    async runSafe() {
        const exportPath = this.flags.path
            ? path_1.default.join(this.flags.path, this.args.index)
            : this.args.index;
        const query = this.parseJs(this.flags.query);
        this.logInfo(`Dumping index "${this.args.index}" in ${exportPath}${path_1.default.sep} ...`);
        fs_1.default.mkdirSync(exportPath, { recursive: true });
        const { collections } = await this.sdk.collection.list(this.args.index);
        for (const collection of collections) {
            try {
                if (collection.type === "realtime") {
                    continue;
                }
                if (this.flags.type === "all" || this.flags.type === "mappings") {
                    this.logInfo(`Dumping collection "${collection.name}" mappings ...`);
                    await (0, dump_collection_1.dumpCollectionMappings)(this.sdk, this.args.index, collection.name, exportPath, this.flags.format);
                }
                if (this.flags.type === "all" || this.flags.type === "data") {
                    this.logInfo(`Dumping collection "${collection.name}" documents ...`);
                    await (0, dump_collection_1.dumpCollectionData)(this.sdk, this.args.index, collection.name, Number(this.flags["batch-size"]), exportPath, query, this.flags.format, this.flags.scrollTTL);
                }
                cli_ux_1.default.action.stop();
            }
            catch (error) {
                this.logKo(`Error when exporting collection "${collection.name}": ${error}`);
            }
        }
        this.logOk(`Index ${this.args.index} dumped`);
    }
}
exports.default = IndexExport;
IndexExport.keepAuth = true;
IndexExport.description = "Exports an index (JSONL or Kuzzle format)";
IndexExport.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), path: command_1.flags.string({
        description: "Dump root directory",
    }), "batch-size": command_1.flags.string({
        description: "Maximum batch size (see limits.documentsFetchCount config)",
        default: "2000",
    }), query: command_1.flags.string({
        description: "Only dump documents in collections matching the query (JS or JSON format)",
        default: "{}",
    }), format: command_1.flags.string({
        description: '"jsonl or kuzzle - kuzzle will export in Kuzzle format usable for internal fixtures and jsonl allows to import that data back with kourou',
        default: "jsonl",
    }), scrollTTL: command_1.flags.string({
        description: `The scroll TTL option to pass to the dump operation (which performs a document.search under the hood),
expressed in ms format, e.g. '2s', '1m', '3h'.`,
        default: "20s",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }), type: command_1.flags.string({
        description: "Type of the export: all, mappings, data",
        default: "all",
    }) });
IndexExport.args = [{ name: "index", description: "Index name", required: true }];
IndexExport.examples = [
    "kourou index:export nyc-open-data",
    'kourou index:export nyc-open-data --query \'{"range":{"_kuzzle_info.createdAt":{"gt":1632935638866}}}\'',
];
