"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
const restore_collection_1 = require("../../support/restore-collection");
class IndexImport extends common_1.Kommand {
    async runSafe() {
        if (this.flags.index) {
            this.logInfo(`Start importing dump from ${this.args.path} in index ${this.flags.index}`);
        }
        else {
            this.logInfo(`Start importing dump from ${this.args.path} in same index`);
        }
        const dumpDirs = fs_1.default
            .readdirSync(this.args.path)
            .map((f) => path_1.default.join(this.args.path, f));
        for (const dumpDir of dumpDirs) {
            try {
                if (!this.flags["no-mappings"]) {
                    const mappingsPath = path_1.default.join(dumpDir, "mappings.json");
                    const dump = JSON.parse(fs_1.default.readFileSync(mappingsPath, "utf8"));
                    await (0, restore_collection_1.restoreCollectionMappings)(this.sdk, dump, this.flags.index);
                }
                const { total, collection, index: dstIndex, } = await (0, restore_collection_1.restoreCollectionData)(this.sdk, this.log.bind(this), Number(this.flags["batch-size"]), path_1.default.join(dumpDir, "documents.jsonl"), this.flags.index);
                this.logOk(`Successfully imported ${total} documents in "${dstIndex}:${collection}"`);
            }
            catch (error) {
                this.logKo(`Error when importing collection from "${dumpDir}": ${error}`);
            }
        }
    }
}
exports.default = IndexImport;
IndexImport.keepAuth = true;
IndexImport.description = "Imports an index (JSONL format)";
IndexImport.examples = [
    "kourou index:import ./dump/iot-data",
    "kourou index:import ./dump/iot-data --index iot-data-production --no-mappings",
];
IndexImport.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), "batch-size": command_1.flags.string({
        description: "Maximum batch size (see limits.documentsWriteCount config)",
        default: "200",
    }), index: command_1.flags.string({
        description: "If set, override the index destination name",
    }), "no-mappings": command_1.flags.boolean({
        description: "Skip collections mappings",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }) });
IndexImport.args = [
    { name: "path", description: "Dump directory or file", required: true },
];
