"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstanceLogs = void 0;
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const command_1 = require("@oclif/command");
const inquirer_1 = (0, tslib_1.__importDefault)(require("inquirer"));
const cli_ux_1 = (0, tslib_1.__importDefault)(require("cli-ux"));
const child_process_1 = require("child_process");
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const node_emoji_1 = (0, tslib_1.__importDefault)(require("node-emoji"));
const common_1 = require("../../common");
const execute_1 = require("../../support/execute");
class InstanceLogs extends common_1.Kommand {
    async runSafe() {
        this.createKourouDir();
        let instance = this.flags.instance;
        const all = this.flags.all;
        const instancesList = await this.getInstancesList();
        if (instancesList.length === 0) {
            throw new Error("There are no Kuzzle running instances");
        }
        if (all) {
            for (const i of instancesList) {
                await this.killInstance(i);
            }
            return;
        }
        if (!instance) {
            const responses = await inquirer_1.default.prompt([
                {
                    name: "instance",
                    message: "Which kuzzle instance do you want to kill",
                    type: "list",
                    choices: instancesList,
                },
            ]);
            if (!responses.instance) {
                throw new Error("A running instance must be selected");
            }
            instance = responses.instance;
        }
        else if (!instancesList.includes(instance)) {
            throw new Error(`The instance parameter you setted ${instance} isn't running`);
        }
        await this.killInstance(instance);
    }
    async killInstance(instanceName) {
        const docoFilename = path_1.default.join(this.kourouDir, `kuzzle-${instanceName}.yml`);
        cli_ux_1.default.action.start(`${node_emoji_1.default.get("boom")}  Killing Kuzzle instance ${instanceName}`, undefined, {
            stdout: true,
        });
        const instanceKill = (0, child_process_1.spawn)("docker", [
            "compose",
            "-f",
            docoFilename,
            "-p",
            instanceName,
            "down",
        ]);
        return new Promise((resolve) => instanceKill.on("close", (code) => {
            if (code === 0) {
                cli_ux_1.default.action.stop(chalk_1.default.green(`\n${node_emoji_1.default.get("thumbsup")}  Instance ${instanceName} successfully killed.`));
            }
            else {
                cli_ux_1.default.action.stop(chalk_1.default.red(`\n${node_emoji_1.default.get("thumbsdown")}  Something went wrong whilde killing instance ${instanceName}.`));
            }
            resolve(undefined);
        }));
    }
    async getInstancesList() {
        let containersListProcess;
        try {
            containersListProcess = await (0, execute_1.execute)("docker", "ps", "--format", '"{{.Names}}"');
        }
        catch (error) {
            this.warn(`Something went wrong while getting kuzzle running instances list: ${error.message}`);
            return [];
        }
        const containersList = containersListProcess.stdout
            .replace(/"/g, "")
            .split("\n");
        return containersList
            .filter((containerName) => containerName.includes("kuzzle") &&
            !containerName.includes("redis") &&
            !containerName.includes("elasticsearch"))
            .map((containerName) => containerName.split("_")[0]);
    }
}
exports.InstanceLogs = InstanceLogs;
InstanceLogs.initSdk = false;
InstanceLogs.description = "Stop and remove all the containers of a running kuzzle instance";
InstanceLogs.flags = {
    instance: command_1.flags.string({
        char: "i",
        description: "Kuzzle instance name [ex: stack-0]",
    }),
    all: command_1.flags.boolean({
        char: "a",
        description: "Kill all instances",
    }),
};
