"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstanceList = void 0;
const common_1 = require("../../common");
const execute_1 = require("../../support/execute");
class InstanceList extends common_1.Kommand {
    async runSafe() {
        const instancesList = await this.getInstancesList();
        // eslint-disable-next-line no-console
        console.table(instancesList, [
            "name",
            "status",
            "kuzzleVersion",
            "kuzzlePort",
            "esVersion",
            "esPort",
            "redisVersion",
            "redisPort",
        ]);
    }
    async getInstancesList() {
        let containersListProcess;
        try {
            containersListProcess = await (0, execute_1.execute)("docker", "ps", "--format", '"{{.Names}}%{{.Image}}%{{.Status}}%{{.Ports}}"');
        }
        catch (_a) {
            this.warn("Something went wrong while getting kuzzle running instances list");
            return [];
        }
        let containersList = containersListProcess.stdout
            .replace(/"/g, "")
            .split("\n");
        containersList = containersList.filter((c) => c.match(/stack-\d{0,3}_kuzzle_1/) ||
            c.match(/stack-\d{0,3}_elasticsearch_1/) ||
            c.match(/stack-\d{0,3}_redis_1/));
        const stacks = [
            ...new Set(containersList.map((container) => container.split("_")[0])),
        ].sort((stackA, stackB) => stackA > stackB ? 1 : stackA < stackB ? -1 : 0);
        const formatedStacks = stacks.map((stack) => ({
            name: stack,
            status: "",
            kuzzleVersion: 0,
            kuzzlePort: 0,
            redisVersion: 0,
            redisPort: 0,
            esVersion: 0,
            esPort: 0,
        }));
        for (const container of containersList) {
            const splitted = container.split("%");
            const stackNumber = parseInt(splitted[0].split("_")[0].split("-")[1], 10);
            const type = splitted[0].split("_")[1];
            const version = parseInt(splitted[1].split(":")[1], 10);
            const port = splitted[3];
            switch (type) {
                case "kuzzle":
                    formatedStacks[stackNumber].status = splitted[2];
                    formatedStacks[stackNumber].kuzzleVersion = version;
                    formatedStacks[stackNumber].kuzzlePort = parseInt(port.substring(port.indexOf("->7512/tcp") - 4, port.indexOf("->7512/tcp")), 10);
                    break;
                case "redis":
                    formatedStacks[stackNumber].redisVersion = version;
                    formatedStacks[stackNumber].redisPort = parseInt(port.replace("/tcp", ""), 10);
                    break;
                case "elasticsearch":
                    formatedStacks[stackNumber].esVersion = version;
                    formatedStacks[stackNumber].esPort = parseInt(port.substring(port.indexOf("->9200/tcp") - 4, port.indexOf("->9200/tcp")), 10);
                    break;
            }
        }
        return formatedStacks;
    }
}
exports.InstanceList = InstanceList;
InstanceList.initSdk = false;
InstanceList.description = "Lists the Kuzzle running instances";
