"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstanceLogs = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = (0, tslib_1.__importDefault)(require("inquirer"));
const common_1 = require("../../common");
const execute_1 = require("../../support/execute");
class InstanceLogs extends common_1.Kommand {
    async runSafe() {
        let instance = this.flags.instance;
        const followOption = this.flags.follow;
        if (!instance) {
            const instancesList = await this.getInstancesList();
            if (instancesList.length === 0) {
                throw new Error("There are no Kuzzle running instances");
            }
            const responses = await inquirer_1.default.prompt([
                {
                    name: "instance",
                    message: "On which kuzzle instance do you want to see the logs",
                    type: "list",
                    choices: instancesList,
                },
            ]);
            if (!responses.instance) {
                throw new Error("A running Kuzzle instance must be selected.");
            }
            instance = responses.instance;
        }
        await this.showInstanceLogs(instance, followOption);
    }
    async showInstanceLogs(instanceName, followOption) {
        var _a, _b;
        const args = ["logs", instanceName];
        if (followOption) {
            args.push("-f");
        }
        const instanceLogs = (0, execute_1.execute)("docker", ...args);
        (_a = instanceLogs.process.stdout) === null || _a === void 0 ? void 0 : _a.pipe(process.stdout);
        (_b = instanceLogs.process.stderr) === null || _b === void 0 ? void 0 : _b.pipe(process.stderr);
        await instanceLogs;
    }
    async getInstancesList() {
        let containersListProcess;
        try {
            containersListProcess = await (0, execute_1.execute)("docker", "ps", "--format", '"{{.Names}}"');
        }
        catch (_a) {
            this.warn("Something went wrong while getting kuzzle running instances list");
            return [];
        }
        const containersList = containersListProcess.stdout
            .replace(/"/g, "")
            .split("\n");
        return containersList.filter((containerName) => containerName.includes("kuzzle") &&
            !containerName.includes("redis") &&
            !containerName.includes("elasticsearch"));
    }
}
exports.InstanceLogs = InstanceLogs;
InstanceLogs.initSdk = false;
InstanceLogs.description = "Displays the logs of a running Kuzzle";
InstanceLogs.flags = {
    instance: command_1.flags.string({
        char: "i",
        description: "Kuzzle instance name",
    }),
    follow: command_1.flags.boolean({
        char: "f",
        description: "Follow log output",
    }),
};
