"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const command_1 = require("@oclif/command");
const PaasKommand_1 = require("../../support/PaasKommand");
class PaasInit extends PaasKommand_1.PaasKommand {
    async runSafe() {
        const packageJsonPath = path_1.default.join(process.cwd(), "package.json");
        if (!fs_1.default.existsSync(packageJsonPath)) {
            throw new Error(`Cannot find package json in current directory. (${packageJsonPath})`);
        }
        const packageJson = JSON.parse(fs_1.default.readFileSync(packageJsonPath, "utf8"));
        this.logInfo('Add the "kuzzle" property inside project package.json.');
        packageJson.kuzzle = {
            paas: {
                project: this.args.project,
            },
        };
        fs_1.default.writeFileSync(packageJsonPath, JSON.stringify(packageJson, null, 2));
    }
}
PaasInit.description = "Initialize a PaaS project in current directory";
PaasInit.flags = {
    help: command_1.flags.help(),
};
PaasInit.args = [
    {
        name: "project",
        description: "Kuzzle PaaS project name",
        required: true,
    },
];
exports.default = PaasInit;
