"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const node_fetch_1 = (0, tslib_1.__importDefault)(require("node-fetch"));
const command_1 = require("@oclif/command");
const cli_ux_1 = (0, tslib_1.__importDefault)(require("cli-ux"));
const PaasKommand_1 = require("../../support/PaasKommand");
const child_process_1 = require("child_process");
class PaasLogin extends PaasKommand_1.PaasKommand {
    async runSafe() {
        this.createKourouDir();
        const username = this.flags.username
            ? this.flags.username
            : await cli_ux_1.default.prompt(`    Username`);
        const password = process.env.KUZZLE_PAAS_PASSWORD
            ? process.env.KUZZLE_PAAS_PASSWORD
            : await cli_ux_1.default.prompt(`    Password`, { type: "hide" });
        if (this.flags.only_npm) {
            await this.authenticateNPM(username, password);
            return;
        }
        await this.initPaasClient({ username, password });
        await this.authenticateNPM(username, password);
        const apiKey = await this.paas.auth.createApiKey("Kourou PaaS API Key");
        this.createProjectCredentials(apiKey);
        this.logOk(`Successfully logged in as ${username}. Your Kuzzle Enterprise license is now enabled on this host.`);
    }
    createProjectCredentials(apiKey) {
        const project = this.getProject();
        const projectFile = this.fileProjectCredentials(project);
        const credentials = {
            apiKey: apiKey._source.token,
        };
        this.logInfo(`Saving credentials for project "${project}" in "${projectFile}".`);
        fs_1.default.writeFileSync(projectFile, JSON.stringify(credentials, null, 2));
        fs_1.default.chmodSync(projectFile, 0o600);
    }
    async authenticateNPM(username, password) {
        const options = {
            method: "PUT",
            headers: {
                "Content-Type": "application/json",
                Accept: "application/json",
                Authorization: `Basic ${Buffer.from(`${username}:${password}`).toString("base64")}`,
            },
            body: JSON.stringify({
                name: username,
                password,
            }),
        };
        const targetUrl = `https://${this.packagesHost}/-/user/org.couchdb.user:${username}`;
        const response = await (0, node_fetch_1.default)(targetUrl, options);
        const json = await response.json();
        if (response.status !== 201) {
            throw new Error(json.error);
        }
        const { token } = json;
        (0, child_process_1.spawnSync)("npm", [
            "config",
            "set",
            "@kuzzleio:registry",
            `https://${this.packagesHost}`,
        ], { stdio: "inherit" });
        (0, child_process_1.spawnSync)("npm", ["set", `//${this.packagesHost}/:_authToken`, token], {
            stdio: "inherit",
        });
    }
}
PaasLogin.description = "Login for a PaaS project";
PaasLogin.flags = {
    help: command_1.flags.help(),
    project: command_1.flags.string({
        description: "Current PaaS project",
        required: false,
    }),
    username: command_1.flags.string({
        description: "PaaS username",
    }),
    only_npm: command_1.flags.boolean({
        description: "Only perform the login on the private NPM registry",
        required: false,
        default: false,
    }),
};
exports.default = PaasLogin;
