"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const PaasKommand_1 = require("../../../support/PaasKommand");
class PaasSnapshotsCat extends PaasKommand_1.PaasKommand {
    async runSafe() {
        const apiKey = await this.getCredentials();
        await this.initPaasClient({ apiKey });
        const user = await this.paas.auth.getCurrentUser();
        this.logInfo(`Logged as "${user._id}" for project "${this.flags.project || this.getProject()}"`);
        const { result } = await this.paas.query({
            controller: "application",
            action: "snapshots",
            environmentId: this.args.environment,
            projectId: this.flags.project || this.getProject(),
            applicationId: this.args.applicationId,
            body: {},
        });
        this.logInfo(JSON.stringify(result, null, 2));
    }
}
PaasSnapshotsCat.description = "List all snapshots for a given kuzzle application in a environment";
PaasSnapshotsCat.flags = {
    help: command_1.flags.help(),
    token: command_1.flags.string({
        default: process.env.KUZZLE_PAAS_TOKEN,
        description: "Authentication token",
    }),
    project: command_1.flags.string({
        description: "Current PaaS project",
    }),
};
PaasSnapshotsCat.args = [
    {
        name: "environment",
        description: "Project environment name",
        required: true,
    },
    {
        name: "applicationId",
        description: "Application Identifier",
        required: true,
    }
];
PaasSnapshotsCat.examples = ["kourou paas:snapshots:cat --project paas-project-myproject api main"];
exports.default = PaasSnapshotsCat;
