"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const PaasKommand_1 = require("../../../support/PaasKommand");
class PaasSnapshotsRestore extends PaasKommand_1.PaasKommand {
    async runSafe() {
        const apiKey = await this.getCredentials();
        await this.initPaasClient({ apiKey });
        const user = await this.paas.auth.getCurrentUser();
        this.logInfo(`Logged as "${user._id}" for project "${this.flags.project || this.getProject()}"`);
        await this.paas.query({
            controller: "application",
            action: "restore",
            environmentId: this.args.environment,
            projectId: this.flags.project || this.getProject(),
            applicationId: this.args.applicationId,
            snapshotId: this.args.snapshotId
        });
        this.logInfo("Ok");
    }
}
PaasSnapshotsRestore.description = "Restore a snapshot of the current application state";
PaasSnapshotsRestore.flags = {
    help: command_1.flags.help(),
    token: command_1.flags.string({
        default: process.env.KUZZLE_PAAS_TOKEN,
        description: "Authentication token",
    }),
    project: command_1.flags.string({
        description: "Current PaaS project",
    }),
};
PaasSnapshotsRestore.args = [
    {
        name: "environment",
        description: "Project environment name",
        required: true,
    },
    {
        name: "applicationId",
        description: "Application Identifier",
        required: true,
    },
    {
        name: "snapshotId",
        description: "Snapshot Identifier",
        required: true,
    }
];
PaasSnapshotsRestore.examples = ["kourou paas:snapshots:restore --project paas-project-myproject api main snapshot-id"];
exports.default = PaasSnapshotsRestore;
