"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class ProfileExport extends common_1.Kommand {
    async runSafe() {
        const filename = path_1.default.join(this.flags.path, "profiles.json");
        this.logInfo(`Exporting profiles in ${filename} ...`);
        fs_1.default.mkdirSync(this.flags.path, { recursive: true });
        const profiles = await this._dumpProfiles();
        const dump = {
            type: "profiles",
            content: profiles,
        };
        fs_1.default.writeFileSync(filename, JSON.stringify(dump, null, 2));
        this.logOk(`${Object.keys(profiles).length} profiles dumped`);
    }
    async _dumpProfiles() {
        const options = {
            scroll: "3s",
            size: 100,
        };
        let result = await this.sdk.security.searchProfiles({}, options);
        const profiles = {};
        while (result) {
            result.hits.forEach((hit) => {
                profiles[hit._id] = { policies: hit.policies };
            });
            result = await result.next();
        }
        return profiles;
    }
}
exports.default = ProfileExport;
ProfileExport.description = "Exports profiles";
ProfileExport.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), path: command_1.flags.string({
        description: "Dump directory",
        default: "profiles",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }) });
