"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class RedisListKeys extends common_1.Kommand {
    async runSafe() {
        const match = this.args.match;
        const count = parseInt(this.flags.size, 10);
        const maxPages = parseInt(this.flags.max, 10);
        this.logInfo(`Start searching for keys matching "${match}...`);
        let keys = [];
        let cursor = "0";
        let pages = 0;
        do {
            const result = await this.sdk.ms.scan(cursor, { count, match });
            cursor = result.cursor;
            for (const key of result.values) {
                keys.push(key);
            }
            pages++;
            process.stdout.write(`Iterate on page ${pages}. ${keys.length} keys found so far.`);
            process.stdout.write("\r");
            if (maxPages !== -1 && pages >= maxPages) {
                break;
            }
        } while (cursor !== "0");
        keys = keys.sort();
        const values = await this.sdk.ms.mget(keys);
        for (let i = 0; i < keys.length; i++) {
            this.log(`"${keys[i]}" = ${values[i]}`);
        }
        if (this.flags.remove) {
            await this.sdk.ms.del(keys);
            this.logOk(`${keys.length} keys deleted`);
        }
        else {
            this.logOk(`${keys.length} keys retrieved`);
        }
    }
}
exports.default = RedisListKeys;
RedisListKeys.description = "Lists keys stored in Redis";
RedisListKeys.flags = Object.assign({ help: command_1.flags.help(), remove: command_1.flags.boolean({
        description: "Remove matching keys",
        default: false,
    }), size: command_1.flags.string({
        description: "Page size",
        default: "100",
    }), max: command_1.flags.string({
        description: "Maximum number of page to retrieve (-1 to retrieve everything)",
        default: "-1",
    }) }, kuzzle_1.kuzzleFlags);
RedisListKeys.args = [
    {
        name: "match",
        description: "Match Redis keys with a pattern",
        default: "*",
    },
];
RedisListKeys.examples = [
    'kourou redis:list-keys "*cluster*"',
    'kourou redis:list-keys "counters/*" --remove',
];
RedisListKeys.readStdin = true;
