"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const command_1 = require("@oclif/command");
const common_1 = require("../../common");
const kuzzle_1 = require("../../support/kuzzle");
class RoleDump extends common_1.Kommand {
    async runSafe() {
        const filename = path_1.default.join(this.flags.path, "roles.json");
        this.logInfo(`Exporting roles in ${filename} ...`);
        fs_1.default.mkdirSync(this.flags.path, { recursive: true });
        const roles = await this._dumpRoles();
        const dump = {
            type: "roles",
            content: roles,
        };
        fs_1.default.writeFileSync(filename, JSON.stringify(dump, null, 2));
        this.logOk(`${Object.keys(roles).length} roles dumped`);
    }
    async _dumpRoles() {
        const options = {
            size: 100,
        };
        let result = await this.sdk.security.searchRoles({}, options);
        const roles = {};
        while (result) {
            result.hits.forEach((hit) => {
                roles[hit._id] = { controllers: hit.controllers };
            });
            result = await result.next();
        }
        return roles;
    }
}
exports.default = RoleDump;
RoleDump.description = "Exports roles";
RoleDump.flags = Object.assign(Object.assign({ help: command_1.flags.help({}), path: command_1.flags.string({
        description: "Dump directory",
        default: "roles",
    }) }, kuzzle_1.kuzzleFlags), { protocol: command_1.flags.string({
        description: "Kuzzle protocol (http or websocket)",
        default: "ws",
    }) });
