"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VaultAdd = void 0;
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const command_1 = require("@oclif/command");
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const kuzzle_vault_1 = require("kuzzle-vault");
const common_1 = require("../../common");
class VaultAdd extends common_1.Kommand {
    async runSafe() {
        if (lodash_1.default.isEmpty(this.flags["vault-key"])) {
            throw new Error("A vault key must be provided");
        }
        if (lodash_1.default.isEmpty(this.args["secrets-file"])) {
            throw new Error("A secrets file must be provided");
        }
        const cryptonomicon = new kuzzle_vault_1.Cryptonomicon(this.flags["vault-key"]);
        const PARSER = kuzzle_vault_1.Vault.getParser(this.args["secrets-file"]);
        let encryptedSecrets = {};
        if (fs_1.default.existsSync(this.args["secrets-file"])) {
            encryptedSecrets = PARSER.parse(fs_1.default.readFileSync(this.args["secrets-file"], "utf8"));
            try {
                cryptonomicon.decryptObject(encryptedSecrets);
            }
            catch (error) {
                throw new Error("Trying to add a secret encrypted with a different key");
            }
        }
        lodash_1.default.set(encryptedSecrets, this.args.key, cryptonomicon.encryptString(this.args.value));
        fs_1.default.writeFileSync(this.args["secrets-file"], PARSER.stringify(encryptedSecrets, null, 2));
        this.logOk(`Key "${this.args.key}" has been securely added "${this.args["secrets-file"]}"`);
    }
}
exports.VaultAdd = VaultAdd;
VaultAdd.initSdk = false;
VaultAdd.description = `
Adds an encrypted key to an encrypted secrets file.

A new secrets file is created if it does not yet exist.

Encrypted secrets are meant to be loaded inside an application with Kuzzle Vault.

See https://github.com/kuzzleio/kuzzle-vault/ for more information.
`;
VaultAdd.examples = [
    "kourou vault:add config/secrets.enc.json aws.s3.keyId b61e267676660c314b006b06 --vault-key <vault-key>",
];
VaultAdd.flags = {
    "vault-key": command_1.flags.string({
        description: "Kuzzle Vault Key (or KUZZLE_VAULT_KEY)",
        default: process.env.KUZZLE_VAULT_KEY,
    }),
};
VaultAdd.args = [
    {
        name: "secrets-file",
        description: "Encrypted secrets file",
        required: true,
    },
    {
        name: "key",
        description: "Path to the key (lodash style)",
        required: true,
    },
    { name: "value", description: "Value to encrypt", required: true },
];
