"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VaultShow = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const kuzzle_vault_1 = require("kuzzle-vault");
const common_1 = require("../../common");
class VaultShow extends common_1.Kommand {
    async runSafe() {
        if (lodash_1.default.isEmpty(this.flags["vault-key"])) {
            throw new Error("A vault key must be provided");
        }
        if (lodash_1.default.isEmpty(this.args["secrets-file"])) {
            throw new Error("A secrets file must be provided");
        }
        const cryptonomicon = new kuzzle_vault_1.Cryptonomicon(this.flags["vault-key"]);
        if (!fs_1.default.existsSync(this.args["secrets-file"])) {
            throw new Error(`File "${this.args["secrets-file"]}" does not exists`);
        }
        const PARSER = kuzzle_vault_1.Vault.getParser(this.args["secrets-file"]);
        let encryptedSecrets = {};
        try {
            encryptedSecrets = PARSER.parse(fs_1.default.readFileSync(this.args["secrets-file"], "utf8"));
        }
        catch (error) {
            throw new Error(`Cannot read secrets from file "${this.args["secrets-file"]}": ${error.message}`);
        }
        if (this.args.key) {
            const encryptedValue = lodash_1.default.get(encryptedSecrets, this.args.key);
            if (!encryptedValue) {
                throw new Error(`Key "${this.args.key}" does not exist`);
            }
            const decryptedValue = cryptonomicon.decryptString(encryptedValue);
            this.logOk(`Key "${this.args.key}" content:`);
            this.log(chalk_1.default.green(decryptedValue));
        }
        else {
            const decryptedSecrets = cryptonomicon.decryptObject(encryptedSecrets);
            this.logOk("Secrets file content:");
            this.log(chalk_1.default.green(PARSER.stringify(decryptedSecrets, null, 2)));
        }
    }
}
exports.VaultShow = VaultShow;
VaultShow.initSdk = false;
VaultShow.description = `
Prints an encrypted secrets file content.

This method can display either:
 - the entire content of the secrets file
 - a single key value

See https://github.com/kuzzleio/kuzzle-vault/ for more information.
`;
VaultShow.examples = [
    "kourou vault:show config/secrets.enc.json --vault-key <vault-key>",
    "kourou vault:show config/secrets.enc.json aws.s3.secretKey --vault-key <vault-key>",
];
VaultShow.flags = {
    "vault-key": command_1.flags.string({
        description: "Kuzzle Vault Key (or KUZZLE_VAULT_KEY)",
        default: process.env.KUZZLE_VAULT_KEY,
    }),
};
VaultShow.args = [
    {
        name: "secrets-file",
        description: "Encrypted secrets file",
        required: true,
    },
    { name: "key", description: "Path to a key (lodash style)" },
];
