"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VaultTest = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const kuzzle_vault_1 = require("kuzzle-vault");
const common_1 = require("../../common");
class VaultTest extends common_1.Kommand {
    async runSafe() {
        if (lodash_1.default.isEmpty(this.flags["vault-key"])) {
            throw new Error("A vault key must be provided");
        }
        if (lodash_1.default.isEmpty(this.args["secrets-file"])) {
            throw new Error("A secrets file must be provided");
        }
        const vault = new kuzzle_vault_1.Vault(this.flags["vault-key"]);
        try {
            vault.decrypt(this.args["secrets-file"]);
            this.logOk("Secrets file can be decrypted");
        }
        catch (error) {
            this.logKo(`Secrets file cannot be decrypted: ${error.message}`);
        }
    }
}
exports.VaultTest = VaultTest;
VaultTest.initSdk = false;
VaultTest.description = `
Tests if an encrypted secrets file can be decrypted.

See https://github.com/kuzzleio/kuzzle-vault/ for more information.
`;
VaultTest.examples = [
    "kourou vault:test config/secrets.enc.json --vault-key <vault-key>",
];
VaultTest.flags = {
    "vault-key": command_1.flags.string({
        description: "Kuzzle Vault Key (or KUZZLE_VAULT_KEY)",
        default: process.env.KUZZLE_VAULT_KEY,
    }),
};
VaultTest.args = [
    {
        name: "secrets-file",
        description: "Encrypted secrets file",
        required: true,
    },
];
