import { Hook } from "@oclif/config";
/**
 * Hooks that run the corresponding API action with sdk:query.
 *
 * Example:
 *  - kourou document:create -i index -c collection --id foobar-1 --body '{}'
 *
 * Index, collection, ID and body can be infered if they are
 * passed as argument in one of the following order:
 *  - <index> <collection> <id> <body>
 *  - <index> <collection> <body>
 *  - <index> <collection> <id>
 *  - <index> <collection>
 *  - <index>
 *  - <body>
 *
 * This is mainly to match easily methods from the document, bulk, realtime
 * and collection controllers.
 *
 * If one of the infered arguments is passed as a flag, then Kourou will
 * use the flag value and will not try to infere arguments.
 *
 * Example:
 *  - kourou document:create index collection foobar-1 '{}'
 *  - kourou bulk:import index collection '{bulkData: []}'
 */
declare const hook: Hook<"command_not_found">;
export default hook;
