"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PaasKommand = void 0;
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const common_1 = require("../common");
const kuzzle_1 = require("./kuzzle");
class PaasKommand extends common_1.Kommand {
    constructor() {
        super(...arguments);
        this.host = process.env.KUZZLE_PAAS_HOST
            ? process.env.KUZZLE_PAAS_HOST
            : "console.paas.kuzzle.io";
        this.port = process.env.KUZZLE_PAAS_PORT
            ? parseInt(process.env.KUZZLE_PAAS_PORT)
            : 443;
        this.ssl = process.env.KUZZLE_PAAS_SSL
            ? JSON.parse(process.env.KUZZLE_PAAS_SSL)
            : true;
        this.packagesHost = process.env.KUZZLE_PAAS_PACKAGES_HOST
            ? process.env.KUZZLE_PAAS_PACKAGES_HOST
            : "packages.paas.kuzzle.io";
        // Instantiate a dummy SDK to avoid the this.paas? notation everywhere -_-
        this.paas = new kuzzle_1.KuzzleSDK({});
    }
    async initPaasClient(credentials) {
        this.paas = new kuzzle_1.KuzzleSDK(Object.assign({ protocol: "http", host: this.host, port: this.port, ssl: this.ssl }, credentials));
        try {
            await this.paas.init(this);
        }
        catch (error) {
            if (error.id === "plugin.strategy.missing_user") {
                this.logKo("Incorrect username or password.");
                process.exit(1);
            }
            throw error;
        }
    }
    fileProjectCredentials(project) {
        return path_1.default.join(this.kourouDir, `${project}.paas.json`);
    }
    /**
     * Retrieve the current project name from the command line or current package.json
     */
    getProject() {
        const packageJsonPath = path_1.default.join(process.cwd(), "package.json");
        if (fs_1.default.existsSync(packageJsonPath)) {
            const packageJson = JSON.parse(fs_1.default.readFileSync(packageJsonPath, "utf8"));
            if (packageJson.kuzzle && packageJson.kuzzle.paas) {
                return packageJson.kuzzle.paas.project;
            }
        }
        if (!this.flags.project) {
            throw new Error("Cannot find PaaS project in package.json or command line");
        }
        return this.flags.project;
    }
    async getCredentials() {
        const project = this.getProject();
        const projectFile = this.fileProjectCredentials(project);
        if (!fs_1.default.existsSync(projectFile)) {
            this.logKo("You are not logged in. You should run paas:login first. Aborting.");
            process.exit(1);
        }
        const credentials = JSON.parse(fs_1.default.readFileSync(projectFile, "utf8"));
        return credentials.apiKey;
    }
}
exports.PaasKommand = PaasKommand;
PaasKommand.initSdk = false;
