"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkPrerequisites = void 0;
const tslib_1 = require("tslib");
const listr_1 = (0, tslib_1.__importDefault)(require("listr"));
const execute_1 = require("../execute");
const MIN_DOCO_VERSION = "2.0.0";
async function checkPrerequisites(ctx) {
    const checks = new listr_1.default([
        {
            title: `docker compose exists and the version is at least ${MIN_DOCO_VERSION}`,
            task: async () => {
                const docov = await (0, execute_1.execute)("docker", "compose", "version");
                const matches = docov.stdout.match(/[^0-9.]*([0-9.]*).*/);
                const docoVersion = matches ? matches[1] : null;
                ctx.logInfo(`Found Docker Compose version: ${docoVersion}`);
                if (!docoVersion) {
                    throw new Error("Unable to read the version of Docker Compose. Are you sure Docker and the Compose plugin are installed?");
                }
                if (docoVersion < MIN_DOCO_VERSION) {
                    throw new Error(`Your version of Docker Compose (${docoVersion}) is below the required version (${MIN_DOCO_VERSION}).`);
                }
            },
        },
    ]);
    try {
        await checks.run();
        return true;
    }
    catch (error) {
        ctx.logKo(error.message);
        return false;
    }
}
exports.checkPrerequisites = checkPrerequisites;
