"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Editor = void 0;
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const child_process_1 = require("child_process");
const tmp_1 = (0, tslib_1.__importDefault)(require("tmp"));
class Editor {
    constructor(content = "", options = {}) {
        this._content = content;
        this.options = options;
        this.defaultEditor = process.platform.startsWith("win")
            ? "notepad"
            : "nano";
        if (this.options.json) {
            if (this._content.length === 0) {
                this._content = "{\n\n}";
            }
            else {
                this._content = JSON.stringify(JSON.parse(this._content), null, 2);
            }
            this.tmpFile = tmp_1.default.fileSync({ postfix: ".json" });
        }
        else {
            this.tmpFile = tmp_1.default.fileSync();
        }
        fs_1.default.writeFileSync(this.tmpFile.name, this._content);
    }
    run() {
        process.env.EDITOR = process.env.EDITOR || this.defaultEditor;
        const editor = process.env.EDITOR;
        const response = (0, child_process_1.spawnSync)(editor, [this.tmpFile.name], {
            stdio: "inherit",
        });
        if (response.status !== 0) {
            // eslint-disable-next-line
            console.error(response.stdout);
            // eslint-disable-next-line
            console.error(response.stderr);
            throw new Error(`Unable to open editor "${editor}": ${response.error}.\nPlease set EDITOR environment variable.`);
        }
        this._content = fs_1.default.readFileSync(this.tmpFile.name, "utf8");
        fs_1.default.unlinkSync(this.tmpFile.name);
    }
    get content() {
        return this._content;
    }
}
exports.Editor = Editor;
