/// <reference types="node" />
import { ChildProcess } from "child_process";
interface ProcessExecutor<T> extends Promise<T> {
    process: ChildProcess;
}
declare type ExecutionResult = {
    stdout: string;
    stderr: string;
    exitCode: number;
};
export declare class ExecutionError extends Error {
    command: string;
    result: ExecutionResult;
    constructor(stderr: string, stdout: string, code: number, command: string[]);
}
/**
 * Executes a command.
 *
 * The given should be given as strings as for the child_process.spawn command.
 * If the last argument is an object, it will be passed to the child_process.spawn command.
 *
 * @example
 * await execute('ls', '-la')
 * await execute('ls', '-la', { cwd: '/home/aschen' })
 * @returns {ProcessExecutor<ExecutionResult>} ProcessExecutor
 */
export declare function execute(...args: any[]): ProcessExecutor<ExecutionResult>;
export {};
