/// <reference types="node" />
import http from "http";
import { flags } from "@oclif/command";
import { Kuzzle, JSONObject } from "kuzzle-sdk";
export declare const kuzzleFlags: {
    host: flags.IOptionFlag<string>;
    port: flags.IOptionFlag<string>;
    ssl: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
    username: flags.IOptionFlag<string>;
    password: flags.IOptionFlag<string | undefined>;
    protocol: flags.IOptionFlag<string>;
    as: flags.IOptionFlag<string | undefined>;
    "api-key": flags.IOptionFlag<string | undefined>;
};
export declare class KuzzleSDK {
    sdk: Kuzzle;
    private host;
    private port;
    private ssl;
    private username;
    private password;
    private protocol;
    private apikey;
    private refreshTimer?;
    private appVersion;
    private appName;
    private ttl;
    private keepAuth;
    constructor(options: any);
    init(logger: any): Promise<void>;
    /**
     * Impersonates a user.
     * Every action called in the given callback will be impersonated.
     *
     * @param {string} userKuid - User kuid to impersonate
     * @param {Function} callback - Callback that will be impersonated
     * @returns {void}
     */
    impersonate(userKuid: string, callback: {
        (): Promise<void>;
    }): Promise<void>;
    disconnect(): void;
    query(request: any): Promise<import("kuzzle-sdk").ResponsePayload<unknown>>;
    /**
     * Query the Kuzzle API and return a streamed response.
     * @param request The request to send to Kuzzle
     * @returns The response stream
     */
    queryHttpStream(request: JSONObject): Promise<http.IncomingMessage>;
    get document(): import("kuzzle-sdk").DocumentController;
    get collection(): import("kuzzle-sdk").CollectionController;
    get index(): import("kuzzle-sdk").IndexController;
    get security(): import("kuzzle-sdk/src/controllers/Security").SecurityController;
    get auth(): import("kuzzle-sdk").AuthController;
    get server(): import("kuzzle-sdk").ServerController;
    get realtime(): import("kuzzle-sdk").RealtimeController;
    get ms(): any;
}
