"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fileExists = exports.File = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const fs_2 = (0, tslib_1.__importDefault)(require("fs"));
class File {
    constructor(path) {
        this.path = path;
    }
    getIndexSpecFile(index) {
        return `${this.path}/${index}.specs.json`;
    }
    getIndexDataFile(index) {
        return `${this.path}/${index}.json`;
    }
    async listIndices(pattern) {
        const data = await fs_1.promises.readdir(this.path);
        return data
            .filter((file) => file.match(/\.specs\.json$/) && file.match(pattern))
            .map((file) => file.replace(/\.specs\.json$/, ""));
    }
    async getIndex(index) {
        const data = await fs_1.promises.readFile(this.getIndexSpecFile(index));
        return JSON.parse(data.toString());
    }
    async createIndex(index, specification) {
        await fs_1.promises.writeFile(this.getIndexSpecFile(index), JSON.stringify(specification));
        await fs_1.promises.writeFile(this.getIndexDataFile(index), ""); // Create empty file for data
    }
    async readData(index) {
        if (!fileExists(this.getIndexDataFile(index))) {
            return [];
        }
        const content = await fs_1.promises.readFile(this.getIndexDataFile(index));
        const data = content
            .toString()
            .replace(/\r\n/g, '\n') // Normalize line endings Windows -> Unix
            .split('\n')
            .map((line) => line
            .trim()) // Remove trailing spaces
            .filter((line) => line.length > 0) // Remove empty lines
            .map((line) => JSON.parse(line));
        return {
            documents: data,
            total: data.length,
        };
    }
    async writeData(index, data) {
        let count = 0;
        for (const line of data) {
            await fs_1.promises.appendFile(this.getIndexDataFile(index), `${JSON.stringify(line)}\n`);
            count++;
        }
        return count;
    }
    async clear() {
        const files = await fs_1.promises.readdir(this.path);
        for (const file of files) {
            await fs_1.promises.unlink(`${this.path}/${file}`);
        }
    }
}
exports.File = File;
function fileExists(filePath) {
    try {
        fs_2.default.accessSync(filePath, fs_1.constants.F_OK);
        return true;
    }
    catch (error) {
        return false;
    }
}
exports.fileExists = fileExists;
