"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.restoreUsers = exports.restoreProfiles = exports.restoreRoles = void 0;
const tslib_1 = require("tslib");
const lodash_1 = (0, tslib_1.__importDefault)(require("lodash"));
const bluebird_1 = (0, tslib_1.__importDefault)(require("bluebird"));
const sleep = (seconds) => new Promise((resolve) => setTimeout(resolve, seconds * 1000));
async function restoreRoles(kommand, dump, preserveAnonymous = false) {
    if (dump.type !== "roles") {
        throw new Error("Dump file does not contain roles definition");
    }
    const anonymousRights = lodash_1.default.get(dump.content, "anonymous.controllers.*.actions.*");
    if (!preserveAnonymous && anonymousRights === false) {
        if (kommand.sdk.username === "anonymous") {
            kommand.logKo('You are currently logged in as "anonymous" and anonymous role rights will be overwritten.');
            kommand.logInfo("Use the --preserve-anonymous flag to keep the default anonymous rights.");
            throw new Error("Please authenticate before importing or use --preserve-anonymous.");
        }
        else {
            kommand.logInfo("Anonymous user rights will be overwritten.");
            kommand.logInfo("Use the --preserve-anonymous flag to keep default anonymous rights.");
            kommand.logInfo("Press CTRL+C to abort or wait 4 sec");
            await sleep(4);
        }
    }
    else if (preserveAnonymous) {
        kommand.logInfo("Anonymous user rights has been preserved.");
        delete dump.content.anonymous;
    }
    const results = await bluebird_1.default.map(Object.entries(dump.content), ([roleId, role]) => kommand.sdk.security.createOrReplaceRole(roleId, role, { force: true }), { concurrency: 10 });
    return results.length;
}
exports.restoreRoles = restoreRoles;
async function restoreProfiles(kommand, dump) {
    if (dump.type !== "profiles") {
        throw new Error("Dump file does not contain profiles definition");
    }
    const results = await bluebird_1.default.map(Object.entries(dump.content), ([profileId, profile]) => kommand.sdk.security.createOrReplaceProfile(profileId, profile, {
        force: true,
    }), { concurrency: 10 });
    return results.length;
}
exports.restoreProfiles = restoreProfiles;
async function restoreUsers(kommand, dump) {
    if (dump.type !== "users") {
        throw new Error("Dump file does not contain users definition");
    }
    const results = await bluebird_1.default.map(Object.entries(dump.content), ([userId, userBody]) => {
        return kommand.sdk.security
            .createUser(userId, userBody)
            .then(() => true)
            .catch((error) => kommand.logKo(`Error importing user ${userId}: ${error.message}`));
    }, { concurrency: 10 });
    return results.filter((success) => success).length;
}
exports.restoreUsers = restoreUsers;
